# Changelog
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

<br>

## [0.2.0] – 2023-10-20
* Add Python 3.12 support
* Drop Python 3.9 support
* Increased `aiohttp` requirement to `~3.9.0b0`
* Enable `speedups` extra of `aiohttp`

<br>

## [0.1.0] – 2023-09-27
* The Python versions supported by this release are 3.9-3.11.
* A few endpoints are implemented as proof-of-concept:
  * `/api/4/key/distribution/nodes`
  * `/api/4/key/overview`
  * `/api/4/key/prevalent_values`
  * `/api/4/key/similar`
  * `/api/4/site/config/geodistribution`

[0.1.0]: https://github.com/timwie/aio-taginfo/releases/tag/v0.1.0
[0.1.0]: https://github.com/timwie/aio-taginfo/releases/tag/v0.2.0
